/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {fetch, openToast} from 'frontend-js-web';

export default function RepositoryBrowserComponent({
	namespace,
	parentFolderId,
	repositoryBrowserURL,
	repositoryId,
}) {
	const fileInput = document.getElementById(`${namespace}file`);

	const onInputChange = () => {
		const formData = new FormData();

		formData.append('file', fileInput.files[0]);

		const uploadFileURL = `${repositoryBrowserURL}?repositoryId=${repositoryId}&parentFolderId=${parentFolderId}`;

		fetch(uploadFileURL, {
			body: formData,
			method: 'PUT',
		})
			.then(() => window.location.reload())
			.catch(() => {
				openToast({
					message: Liferay.Language.get(
						'an-unexpected-error-occurred'
					),
					type: 'danger',
				});
			});
	};

	fileInput.addEventListener('change', onInputChange);

	return {
		dispose() {
			fileInput.removeEventListener('change', onInputChange);
		},
	};
}
