/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {
	fetch,
	getCheckedCheckboxes,
	openConfirmModal,
	openSimpleInputModal,
	openToast,
} from 'frontend-js-web';

export default function propsTransformer({
	additionalProps: {repositoryBrowserURL},
	portletNamespace,
	...otherProps
}) {
	return {
		...otherProps,
		onActionButtonClick: (event, {item}) => {
			if (item?.data?.action === 'deleteEntries') {
				const deleteAction = () => {
					const container = document.getElementById(
						`${portletNamespace}repositoryEntries`
					);

					const repositoryEntryIds = getCheckedCheckboxes(
						container,
						`${portletNamespace}allRowIds`
					);

					fetch(
						`${repositoryBrowserURL}?repositoryEntryIds=${repositoryEntryIds}`,
						{
							method: 'DELETE',
						}
					)
						.then(() => {
							window.location.reload();
						})
						.catch(() => {
							openToast({
								message: Liferay.Language.get(
									'an-unexpected-error-occurred'
								),
								type: 'danger',
							});
						});
				};

				openConfirmModal({
					message: Liferay.Language.get(
						'are-you-sure-you-want-to-delete-this'
					),
					onConfirm: (isConfimed) => {
						if (isConfimed) {
							deleteAction();
						}
					},
				});
			}
		},

		onCreationMenuItemClick: (event, {item}) => {
			if (item?.data?.action === 'addFolder') {
				const createFolderURL = `${repositoryBrowserURL}?repositoryId=${item.data.repositoryId}&parentFolderId=${item.data.parentFolderId}`;

				openSimpleInputModal({
					dialogTitle: Liferay.Language.get('add-folder'),
					formSubmitURL: createFolderURL,
					mainFieldLabel: Liferay.Language.get('name'),
					mainFieldName: 'name',
					method: 'PUT',
					namespace: '',
					onFormSuccess: () => window.location.reload(),
				});
			}
			else if (item?.data?.action === 'uploadFile') {
				const fileInput = document.getElementById(
					`${portletNamespace}file`
				);

				fileInput?.click();
			}
		},
	};
}
